# CreateModelJobDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** |  | 
**outcome_type** | **str** |  | [optional] 
**config** | [**ModelJobConfig**](ModelJobConfig.md) |  | [optional] 
**execution_id** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**project_id** | **str** |  | 
**model_id** | **str** |  | 
**cohort_id** | **str** |  | [optional] 
**dataset_id** | **str** |  | [optional] 
**model_population_id** | **str** |  | [optional] 
**outcome_distribution_histogram_query_id** | **str** |  | [optional] 
**started_at** | **datetime** |  | [optional] 
**ended_at** | **datetime** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

